==> babelplot-2022.4.tar.gz: babelplot-2022.4/babelplot/brick/enum.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2022)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from enum import Enum as enum_t
from typing import Tuple


def EnumMembers(enum: enum_t, /) -> Tuple[str, ...]:
    """"""
    return tuple(sorted(str(_vle) for _, _vle in enum.__members__.items()))


def EnumNames(enum: enum_t, /) -> Tuple[str, ...]:
    """"""
    return tuple(sorted(_vle.name for _, _vle in enum.__members__.items()))


def EnumValues(enum: enum_t, /) -> Tuple[str, ...]:
    """"""
    return tuple(sorted(_vle.value for _, _vle in enum.__members__.items()))

==> babelplot-2022.8.tar.gz: babelplot-2022.8/babelplot/brick/enum.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2022)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from enum import Enum as enum_t


def EnumMembers(enum: enum_t, /) -> tuple[str, ...]:
    """"""
    return tuple(sorted(str(_vle) for _, _vle in enum.__members__.items()))


def EnumNames(enum: enum_t, /) -> tuple[str, ...]:
    """"""
    return tuple(sorted(_vle.name for _, _vle in enum.__members__.items()))


def EnumValues(enum: enum_t, /) -> tuple[str, ...]:
    """"""
    return tuple(sorted(_vle.value for _, _vle in enum.__members__.items()))
